@@ -1,5 +1,5 @@
-from typing import Callable, Deque, List, Optional
 from collections import deque
+from typing import Any, Callable, Deque, List
 
 import numpy as np
 from scipy.optimize import linear_sum_assignment
@@ -8,16 +8,14 @@ from . import pointcloud
 
 
 class ClusterAssigner:
-
     class Cluster:
         def __init__(self, name: str, pointcloud: pointcloud.PointCloud, feature: np.ndarray) -> None:
             self.name = name
             self.pointcloud = pointcloud
             self.feature = feature
 
-
     def __init__(self, dist_fn: Callable, dist_thresh: float) -> None:
-        self._db = deque()
+        self._db: Deque[Any] = deque()
         self._dist_fn = dist_fn
         self._dist_thresh = dist_thresh
 
