@@ -32,6 +32,7 @@ _type_dict = {
 
 def _parse_pcd_header(lines: list) -> Tuple[dict, str]:
     config = {}
+    config["HEIGHT"] = 1
     data_type = "ascii"
     for c in lines:
         c = c.split()
@@ -39,7 +40,7 @@ def _parse_pcd_header(lines: list) -> Tuple[dict, str]:
             continue
         if c[0] == "FIELDS" or c[0] == "SIZE" or c[0] == "TYPE" or c[0] == "COUNT":
             config[c[0]] = c[1:]
-        elif c[0] == "WIDTH" or c[0] == "POINTS":
+        elif c[0] == "WIDTH" or c[0] == "HEIGHT" or c[0] == "POINTS":
             config[c[0]] = int(c[1])
         elif c[0] == "DATA":
             data_type = c[1]
@@ -120,38 +121,56 @@ def load_pcd(fd: Union[IO, str]) -> pointcloud.PointCloud:
         compressed_size, uncompressed_size = struct.unpack("II", fd.read(8))
         compressed_data = fd.read(compressed_size)
         buf = lzf.decompress(compressed_data, uncompressed_size)
+        field_sizes = []
+        for i in range(len(config["FIELDS"])):
+            field_fmt = config["COUNT"][i] if int(config["COUNT"][i]) > 1 else ""
+            field_fmt += _field_dict[config["TYPE"][i] + config["SIZE"][i]]
+            field_sizes.append(struct.calcsize(field_fmt))
         size = struct.calcsize(fmt)
-        for i in range(len(buf) // size):
-            loaddata.append(list(struct.unpack(fmt, buf[(i * size) : ((i + 1) * size)])))
+        field_offsets = [0] + np.cumsum(field_sizes).tolist()[:-1]
+        field_buf = []
+        offset = 0
+        for i, fs in enumerate(field_sizes):
+            step = fs * config["WIDTH"] * config["HEIGHT"]
+            field_buf.append(buf[offset : (offset + step)])
+            offset += step
+        bytedata = bytearray(len(buf))
+        for i in range(config["WIDTH"] * config["HEIGHT"]):
+            for j, fs in enumerate(field_sizes):
+                i_start = i * size + field_offsets[j]
+                i_end = i_start + fs
+                bytedata[i_start : i_end] = field_buf[j][(i * fs) : ((i + 1) * fs)]
+        for i in range(len(bytedata) // size):
+            loaddata.append(list(struct.unpack(fmt, bytedata[(i * size) : ((i + 1) * size)])))
     else:
         raise ValueError(f"Unsupported data type {data_type}.")
 
     for data in loaddata:
         pc.data.append(np.zeros(pc.field.size()))
         for f, d in zip(config["FIELDS"], data):
-            if f == "x":
-                pc.data[-1][pc.field.X] = d
-            elif f == "y":
-                pc.data[-1][pc.field.Y] = d
-            elif f == "z":
-                pc.data[-1][pc.field.Z] = d
-            elif f == "rgb":
+            index = pc.field.get_field_index(f)
+            if index is None:
+                continue
+            if f == "rgb":
                 d = int(d)
                 pc.data[-1][pc.field.R] = float((d >> 16) & 0x000FF) / 255.0
                 pc.data[-1][pc.field.G] = float((d >> 8) & 0x000FF) / 255.0
                 pc.data[-1][pc.field.B] = float((d) & 0x000FF) / 255.0
-            elif f == "normal_x":
-                pc.data[-1][pc.field.NX] = d
-            elif f == "normal_y":
-                pc.data[-1][pc.field.NY] = d
-            elif f == "normal_z":
-                pc.data[-1][pc.field.NZ] = d
+            else :
+                pc.data[-1][index] = d
 
     pc.finalize()
     return pc
 
 
 def load_stl(fd: Union[IO, str], scale: float = 1.0) -> pointcloud.PointCloud:
+    """Load STL file format
+
+    Parameters
+    ----------
+    fd: BinaryIO, TextIO or str
+        Input file name or StringIO data type.
+    """
     if isinstance(fd, str):
         fd = open(fd, "rb")
     mesh = stl.mesh.Mesh.from_file("", fh=fd)
@@ -159,6 +178,13 @@ def load_stl(fd: Union[IO, str], scale: float = 1.0) -> pointcloud.PointCloud:
 
 
 def load_ply(fd: Union[IO, str]) -> pointcloud.PointCloud:
+    """Load PLY file format
+
+    Parameters
+    ----------
+    fd: BinaryIO, TextIO or str
+        Input file name or StringIO data type.
+    """
     if isinstance(fd, str):
         fd = open(fd, "rb")
     plydata = PlyData.read(fd)
