@@ -17,7 +17,7 @@ class FieldBase(object):
     >>> field = FieldBase()
     >>> field.slices = {"hoge": slice(2, 4)}
     >>> arr = np.random.rand(10, 4)
-    >>> arr[:, field("hoge")].shape
+    >>> arr[:, field["hoge"]].shape
     (10, 2)
     """
     def __init__(self) -> None:
@@ -26,6 +26,9 @@ class FieldBase(object):
     def __getitem__(self, name: str) -> slice:
         return self.slices[name]
 
+    def __setitem__(self, name: str, value: slice) -> None:
+        self.slices[name] = value
+
     def size(self) -> int:
         return 0
 
@@ -44,6 +47,16 @@ class PointXYZField(FieldBase):
     def size(self) -> int:
         return 3
 
+    def get_field_index(self, s: str) -> Optional[Union[int, slice]]:
+        if s == "x":
+            return self.X
+        elif s == "y":
+            return self.Y
+        elif s == "z":
+            return self.Z
+        else:
+            return None
+
 
 class PointXYZRGBField(PointXYZField):
     R = 3
@@ -56,6 +69,15 @@ class PointXYZRGBField(PointXYZField):
     def size(self) -> int:
         return 6
 
+    def get_field_index(self, s: str) -> Optional[Union[int, slice]]:
+        index = super(PointXYZNormalField, self).get_field_index(s)
+        if index is not None:
+            return index
+        if s == "rgb":
+            return self.slices["color"]
+        else:
+            return None
+
 
 class PointXYZRGBAField(PointXYZField):
     R = 3
@@ -69,6 +91,15 @@ class PointXYZRGBAField(PointXYZField):
     def size(self) -> int:
         return 7
 
+    def get_field_index(self, s: str) -> Optional[Union[int, slice]]:
+        index = super(PointXYZNormalField, self).get_field_index(s)
+        if index is not None:
+            return index
+        if s == "rgba":
+            return slice(self.slices["color"].start, self.slices["alpha"].stop)
+        else:
+            return None
+
 
 class PointXYZNormalField(PointXYZField):
     NX = 3
@@ -81,6 +112,19 @@ class PointXYZNormalField(PointXYZField):
     def size(self) -> int:
         return 6
 
+    def get_field_index(self, s: str) -> Optional[Union[int, slice]]:
+        index = super(PointXYZNormalField, self).get_field_index(s)
+        if index is not None:
+            return index
+        if s == "normal_x":
+            return self.NX
+        elif s == "normal_y":
+            return self.NY
+        elif s == "normal_z":
+            return self.NZ
+        else:
+            return None
+
 
 class PointXYZRGBNormalField(PointXYZRGBField):
     NX = 6
@@ -93,6 +137,19 @@ class PointXYZRGBNormalField(PointXYZRGBField):
     def size(self) -> int:
         return 9
 
+    def get_field_index(self, s: str) -> Optional[Union[int, slice]]:
+        index = super(PointXYZRGBNormalField, self).get_field_index(s)
+        if index is not None:
+            return index
+        if s == "normal_x":
+            return self.NX
+        elif s == "normal_y":
+            return self.NY
+        elif s == "normal_z":
+            return self.NZ
+        else:
+            return None
+
 
 class DynamicField(FieldBase):
     def __init__(self, init_field: Optional[FieldBase] = None) -> None:
@@ -129,7 +186,7 @@ class PointCloud(object):
     (10, 3)
 
     How to specify the point field directly.
-    >>> points = pc.get_field("point")
+    >>> points = pc["point"]
     >>> points.shape
     (10, 3)
     Or,
@@ -157,12 +214,21 @@ class PointCloud(object):
     def __len__(self) -> int:
         return len(self.data)
 
+    def __getitem__(self, key: str) -> np.ndarray:
+        return self.get_field(key)
+
+    def __setitem__(self, key: str, value: np.ndarray) -> None:
+        self.set_field(key, value)
+
     def has_field(self, name: str) -> bool:
         return self.field.has_field(name)
 
     def get_field(self, name: str) -> np.ndarray:
         return self.finalize().data[:, self.field[name]]
 
+    def set_field(self, name: str, value: np.ndarray) -> None:
+        self.finalize().data[:, self.field[name]] = value
+
     def finalize(self) -> PointCloud:
         if isinstance(self.data, list):
             self.data = np.array(self.data)
